import unittest
from tamilrulepy.euphonic import get 

 
class Test_Uyirmayaṅkiyal(unittest.TestCase):

    def test_mayaṅkiya_rule_1(self):
        #result = get(["அ","மடம்"])
        #self.assertIn(['அம்மடம்'],result)
        pass

    """
    def test_mayaṅkiya_rule_2(self):
        result = get(["உண","கொண்டான்"])
        self.assertIn(['உணக்கொண்டான்'],result) 
        result = get( ["புலிபோல","கொண்டான்"])
        self.assertIn(["புலிபோலக்கொண்டான்"],result) 
        result = get(["கொள்ளென","கொண்டான்"])
        self.assertIn(['கொள்ளெனக்கொண்டான்'],result) 
        result = get( ["அ","கொண்டான்"])
        self.assertIn(["அக்கொண்டான்"],result) 
        result = get(["ஆங்க","கொண்டான்"])
        self.assertIn(['ஆங்கக்கொண்டான்'],result)  
    
    
    def test_mayaṅkiya_rule_3(self):
        result = get(["அ","ஞாலம்"])
        self.assertIn(['அஞ்ஞாலம்'],result)
        result = get(["அ","நூல்"])
        self.assertIn(['அந்நூல்'],result)
        result = get(["அ","மடம்"])
        self.assertIn(['அம்மடம்'],result)
   
    def test_mayaṅkiya_rule_5(self):
        result = get(["அ","யாழ்"])
        self.assertIn(['அவ்யாழ்'],result)
        result = get(["அ","வளை"])
        self.assertIn(['அவ்வளை'],result) 

    def test_mayaṅkiya_rule_5(self):
        result = get(["அ","அணி"])
        self.assertIn(['அவ்வணி'],result) 
   
    def test_mayaṅkiya_rule_6(self):
        result = get(["அ","இடை"])
        #self.assertIn(['அயிடை'],result) 
        result = get(["அ","வயின்"])
        #self.assertIn(['ஆவயின்'],result) 

    """
